import React from "react";

import { ChevronLeft } from "lucide-react";

import { Link, Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";

interface PageTitleWithLinkProps {
	backLink?: string;
	backLinkText: string;
	title: string;
	// endTime?: string;
	locale: Locale;
	className?: string;
	countdownClassName?: string;
}

const PageTitleWithLink: React.FC<PageTitleWithLinkProps> = ({
	backLinkText,
	title,
	locale,

	className,
}) => {
	const isRTL = locale === "ar";
	return (
		<div
			className={cn(
				"mb-8 flex items-center justify-between",
				isRTL && "flex-row-reverse",
				className
			)}
		>
			<Link
				href={"/"}
				className={cn(
					"flex items-center gap-2 text-[#2895C8] transition-colors hover:text-[#2895C8]/80",
					isRTL && "flex-row-reverse"
				)}
			>
				<ChevronLeft
					className={cn("h-6 w-6", !isRTL && "rotate-180 transform")}
				/>
				<span className="text-md">{backLinkText}</span>
			</Link>
			<div
				className={cn("flex items-center gap-4", isRTL && "flex-row-reverse")}
			>
				{/* <CountdownTimer
          endTime={endTime}
          locale={locale}
          className={cn(
            "rounded-2xl bg-[#2895C8] px-4 py-1 text-white",
            countdownClassName
          )}
        /> */}
				<h2 className="text-2xl text-gray-900">{title}</h2>
			</div>
		</div>
	);
};

export default PageTitleWithLink;
